@@ -19,7 +19,7 @@ class ClinicalQualityMeasure138v6p1(ClinicalQualityMeasure138v6):
         title = 'Preventive Care and Screening: Tobacco Use: Screening'
         version = '2019-04-18v1'
         description = 'Patients aged 18 years and older who have not been screened for tobacco use in the last year.'  # noqa: E501
-        information = 'https://ecqi.healthit.gov/ecqm/measures/cms138v6'
+        information = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS138v6.html'
 
         identifiers = ['CMS138v6p1']
 
