@@ -9,8 +9,8 @@ from canvas_workflow_kit.protocol import (
 )
 from canvas_workflow_kit.recommendation import Recommendation
 from canvas_workflow_kit.timeframe import Timeframe
-from canvas_workflow_kit.value_set.specials import LabReportCreatinine
-from canvas_workflow_kit.value_set.v2018 import HypertensiveChronicKidneyDisease, KidneyFailure
+from canvas_workflow_kit.value_set.specials import KidneyFailure, LabReportCreatinine
+from canvas_workflow_kit.value_set.v2018 import HypertensiveChronicKidneyDisease
 
 
 class Hcc002v2(ClinicalQualityMeasure):
@@ -22,7 +22,8 @@ class Hcc002v2(ClinicalQualityMeasure):
 
         description = ('All patients with evidence of two or more elevated eGFR values '
                        'and no active CKD problem on the Conditions List.')
-        information = 'https://canvas-medical.zendesk.com/hc/en-us/articles/360059083713-CKD-Suspect-HCC002v2'  # noqa: E501
+        information = ('https://canvas-medical.zendesk.com/hc/en-us/articles/'
+                       '360059083713-CKD-Suspect-HCC002v2')  # noqa: E501
 
         identifiers = ['HCC002v2']
 
@@ -35,9 +36,10 @@ class Hcc002v2(ClinicalQualityMeasure):
             'Canvas Medical Team',
         ]
 
-        references = [
-            'Canvas Medical HCC, https://canvas-medical.zendesk.com/hc/en-us/articles/360059083713-CKD-Suspect-HCC002v2'  # noqa: E501
-        ]
+        references = [(
+            'Canvas Medical HCC, '
+            'https://canvas-medical.zendesk.com/hc/en-us/articles/360059083713-CKD-Suspect-HCC002v2'  # noqa: E501
+        )]
 
         compute_on_change_types = [
             ClinicalQualityMeasure.CHANGE_PROTOCOL_OVERRIDE,
