@@ -4,6 +4,8 @@ from builtins import bool
 from typing import Any, Dict, List, Optional, Type
 
 import arrow
+import inspect
+from functools import reduce
 
 from canvas_workflow_kit.patient_recordset import (
     AdministrativeDocumentRecordSet,
@@ -33,10 +35,17 @@ from canvas_workflow_kit.internal.attrdict import to_attr_dict
 from canvas_workflow_kit.timeframe import Timeframe
 from canvas_workflow_kit.value_set.value_set import ValueSet
 
+# For has_visit_within
+from canvas_workflow_kit.value_set.v2022 import encounter
+
 # from protocols.value_set.v2018 import (DischargedToHealthCareFacilityForHospiceCare,
 #                                  DischargedToHomeForHospiceCare, HomeHealthcareServices,
 #                                  HospiceCareAmbulatory)
 
+ALL_ENCOUNTERS = reduce(lambda x, y: x | y,
+    [c[1] for c in inspect.getmembers(encounter, inspect.isclass) if issubclass(c[1], ValueSet)]
+)
+
 
 class Patient:
     """
@@ -228,14 +237,13 @@ class Patient:
 
     def has_visit_within(self, timeframe: Timeframe,
                          encounters: Optional[Type[ValueSet]] = None) -> bool:
-        if not encounters:
-            return True
+
         return bool(self.count_visit_within(timeframe, encounters) > 0)
 
     def count_visit_within(self, timeframe: Timeframe,
                            encounters: Optional[Type[ValueSet]] = None) -> int:
         if not encounters:
-            return 0
+            encounters = ALL_ENCOUNTERS
 
         recordset = (self
                      .billing_line_items
@@ -243,7 +251,15 @@ class Patient:
                      .before(timeframe.end)
                      .find(encounters))  # yapf: disable
 
-        return len(recordset.records) if recordset else 0
+        reason_for_visit_qs = (self.reason_for_visits
+            .after(timeframe.start)
+            .before(timeframe.end)
+            .find(encounters))
+
+        num_billing_lines = len(recordset.records) if recordset else 0
+        num_reasons_for_visit = len(reason_for_visit_qs.records) if reason_for_visit_qs else 0
+
+        return num_billing_lines + num_reasons_for_visit
 
     def as_dict(self) -> Dict[str, Any]:
         return {
